package com.ruoyi.ems.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.ems.domain.ElecLoadIndex;
import com.ruoyi.ems.service.IElecLoadIndexService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 电力负荷设施指标Controller
 * 
 * @author ruoyi
 * @date 2024-08-09
 */
@RestController
@RequestMapping("/loadIndex")
@Api(value = "ElecLoadIndexController", description = "电力负荷设施指标数据接口")
public class ElecLoadIndexController extends BaseController
{
    @Autowired
    private IElecLoadIndexService emsElecLoadIndexService;

    /**
     * 查询电力负荷设施指标列表
     */
    @RequiresPermissions("ems:loadIndex:list")
    @GetMapping("/list")
    public TableDataInfo list(ElecLoadIndex admEmsElecLoadIndex)
    {
        startPage();
        List<ElecLoadIndex> list = emsElecLoadIndexService.selectElecLoadIndexList(admEmsElecLoadIndex);
        return getDataTable(list);
    }

    /**
     * 导出电力负荷设施指标列表
     */
    @RequiresPermissions("ems:loadIndex:export")
    @Log(title = "电力负荷设施指标", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ElecLoadIndex admEmsElecLoadIndex)
    {
        List<ElecLoadIndex> list = emsElecLoadIndexService.selectElecLoadIndexList(admEmsElecLoadIndex);
        ExcelUtil<ElecLoadIndex> util = new ExcelUtil<ElecLoadIndex>(ElecLoadIndex.class);
        util.exportExcel(response, list, "电力负荷设施指标数据");
    }

    /**
     * 获取电力负荷设施指标详细信息
     */
    @RequiresPermissions("ems:loadIndex:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(emsElecLoadIndexService.selectElecLoadIndexById(id));
    }

    /**
     * 新增电力负荷设施指标
     */
    @RequiresPermissions("ems:loadIndex:add")
    @Log(title = "电力负荷设施指标", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ElecLoadIndex admEmsElecLoadIndex)
    {
        return toAjax(emsElecLoadIndexService.insertElecLoadIndex(admEmsElecLoadIndex));
    }

    /**
     * 修改电力负荷设施指标
     */
    @RequiresPermissions("ems:loadIndex:edit")
    @Log(title = "电力负荷设施指标", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ElecLoadIndex admEmsElecLoadIndex)
    {
        return toAjax(emsElecLoadIndexService.updateElecLoadIndex(admEmsElecLoadIndex));
    }

    /**
     * 删除电力负荷设施指标
     */
    @RequiresPermissions("ems:loadIndex:remove")
    @Log(title = "电力负荷设施指标", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(emsElecLoadIndexService.deleteElecLoadIndexByIds(ids));
    }
}
